zem_version="1.1"
zem_perl="$PLUGINS_DIR/entry/mod/zemanta.pl"
zem_data_dir="$BLOG_DIR/zemanta_cache"
zem_data_dirstamp="$BLOG_DIR/zemanta_cache/stamp"
zem_data_file="$zem_data_dir/$NB_EntryID"
zem_perl_bin="perl"

zem_error="0"

function zem_check_config {
	if [ -z "$ZEM_APIKEY" ]; then
		echo "ERROR:"
		echo "    Can't find your API key in the nanoblogger configuration file."
		echo "    You should add the following line to \"$BLOG_DIR/blog.conf\":"
		echo "    ZEM_APIKEY=\"your_api_key_here\""
		echo ""
		return 1
	fi

	if [ ! -f "$zem_perl" ]; then
		echo "ERROR:"
		echo "    Can't find Perl back-end part of the plugin ($zem_perl)."
		echo "    Try reinstalling."
		echo ""
		return 1
	fi	
	
	if [ ! -d "$zem_data_dir" ]; then
		mkdir "$zem_data_dir"

		if [ ! -d "$zem_data_dir" ]; then
			echo "ERROR:"
			echo "    Can't create data directory ($zem_data_dir)."
			echo "    Check permissions."
			echo ""
			return 1
		fi
	fi

	if [ ! -f "$zem_data_dirstamp" ]; then
		touch "$zem_data_dirstamp"
	fi

	return 0
}

function zem_server_error {
	echo "WARNING:"
	echo "    Can't talk with server. Please try again later."
	echo ""
	zem_error="1"
}

function zem_call {
	"$zem_perl_bin" "$zem_perl" -key "$ZEM_APIKEY" "$@"
}

function zem_create_new_file {
	echo "Zemanta Suggest plugin version $zem_version initializing"

	echo "Communicating with server"

	zem_in_file=`mktemp /tmp/zem.XXXXXX`
	zem_out_file=`mktemp /tmp/zem.XXXXXX`

	echo "$NB_EntryBody" > "$zem_in_file"

	if [ -z "$ZEM_KEYWORDS" -o "$ZEM_KEYWORDS" = "1" ]; then

		if [ -z "$ZEM_KEYWORDS_ASK" -o "$ZEM_KEYWORDS_ASK" = "1" ]; then
			zem_perl_options="--interactive"
		else
			zem_perl_options="--no-interactive"
		fi

		if ! zem_call "$zem_perl_options" -o "$zem_out_file" keywords "$zem_in_file"; then
			zem_server_error
		fi

		zem_keywords=`cat "$zem_out_file"`

		zem_keywords_part="<p>
<b>Keywords:</b><br/>
$zem_keywords
</p>"
	fi

	if [ -z "$ZEM_IMAGE" -o "$ZEM_IMAGE" = "1" ]; then
		if [ -z "$ZEM_IMAGE_ASK" -o "$ZEM_IMAGE_ASK" = "1" ]; then
			zem_perl_options="--interactive"
		else
			zem_perl_options="--no-interactive"
		fi

		if ! zem_call "$zem_perl_options" -o "$zem_out_file" image "$zem_in_file"; then
			zem_server_error
		fi

		zem_image_part=`cat "$zem_out_file" | sed -e 's/img /img style="float: right; margin-left: 10px; margin-bottom: 10px" /'`
	fi

	if [ -z "$ZEM_RELATED" -o "$ZEM_RELATED" = "1" ]; then
		if [ -z "$ZEM_RELATED_ASK" -o "$ZEM_RELATED_ASK" = "1" ]; then
			zem_perl_options="--interactive"
		else
			zem_perl_options="--no-interactive"
		fi

		if ! zem_call "$zem_perl_options" -o "$zem_out_file" relatedlinks "$zem_in_file"; then
			zem_server_error
		fi

		zem_related=`cat "$zem_out_file"`

		zem_related_part="<p>
<b>Related:</b>
</p>

$zem_related"
	fi

	if [ -z "$ZEM_SMARTLINKS" -o "$ZEM_SMARTLINKS" = "1" ]; then
		if [ -z "$ZEM_SMARTLINKS_ASK" -o "$ZEM_SMARTLINKS_ASK" = "1" ]; then
			zem_perl_options="--interactive"
		else
			zem_perl_options="--no-interactive"
		fi

		if ! zem_call "$zem_perl_options" -o "$zem_out_file" smartlinks "$zem_in_file"; then
			zem_server_error
		fi

		zem_markup_part=`cat "$zem_out_file"`
	else
		zem_markup_part="$NB_EntryBody"
	fi

	if [ "$zem_error" = "1" ]; then
		return
	fi

	rm "$zem_in_file"
	rm "$zem_out_file"

	cat > "$zem_data_file" <<END
<div class="zem-content">
$zem_image_part

$zem_markup_part
</div>

<div class="zem-suggest" style="font-size: x-small">
$zem_keywords_part

$zem_related_part
</div>
END
}

if ! zem_check_config; then
	return
fi

if [ "$ENTRY_FILE" -nt "$zem_data_dirstamp" ]; then

	if [ ! -f "$zem_data_file" ]; then
		zem_create_new_file
	fi

	if [ "$ENTRY_FILE" -nt "$zem_data_file" ]; then
		zem_create_new_file
	fi

	if [ "$zem_error" = "0" ]; then
		NB_EntryBody=`cat "$zem_data_file"`
	fi
fi
